#include "stm32f10x.h"

#ifndef __BME280_H
#define __BME280_H

 typedef struct {

	uint16_t dig_T1;
	int16_t  dig_T2;
	int16_t  dig_T3;
	uint16_t dig_P1;
	int16_t  dig_P2;
	int16_t  dig_P3;
	int16_t  dig_P4;
	int16_t  dig_P5;
	int16_t  dig_P6;
	int16_t  dig_P7;
	int16_t  dig_P8;
	int16_t  dig_P9;
	uint8_t  dig_H1;
	int16_t  dig_H2;
	uint8_t  dig_H3;
	int16_t  dig_H4;
	int16_t  dig_H5;
	int8_t   dig_H6;

} BME280_trimstruct;

//definicje dla adresu
#define adressi2c_1     1  //SDO podlaczone do masy
#define adressi2d_2    0   //SDO podlaczone do zasilania
#define chstatus       1   //sprawdzenie rejestru statusowego

//Uwaga adress musi byc przesuniety o jeden bit w lewo
#if adressi2c_1
#define adressi2c    (0x76<<1)
#else
#define adressi2c    (0x77<<1)
#endif

//nazwy rejestrow
#define bm_hum_lsb     0xfe
#define bm_hum_msb     0xfd
#define bm_temp_xlsb   0xfc
#define bm_temp_lsb    0xfb
#define bm_temp_msb    0xfa
#define bm_press_xlsb  0xf9
#define bm_press_lsb   0xf8
#define bm_press_msb   0xf7
#define bm_config      0xf5
#define bm_ctrl_meas   0xf4
#define bm_status      0xf3
#define bm_ctrl_hum    0xf2
#define bm_calib_26    0xe1
#define bm_calib_27    0xe2
#define bm_calib_28    0xe3
#define bm_calib_29    0xe4
#define bm_calib_30    0xe5
#define bm_calib_31    0xe6
#define bm_calib_32    0xe7
#define bm_calib_33    0xe8
#define bm_calib_34    0xe9
#define bm_calib_35    0xea
#define bm_calib_36    0xeb
#define bm_calib_37    0xec
#define bm_calib_38    0xed
#define bm_calib_39    0xee
#define bm_calib_40    0xef
#define bm_calib_41    0xf0
#define bm_reset       0xe0
#define bm_id          0xd0
#define bm_calib_00    0x88
#define bm_calib_01    0x89
#define bm_calib_02    0x8a
#define bm_calib_03    0x8b
#define bm_calib_04    0x8c
#define bm_calib_05    0x8d
#define bm_calib_06    0x8e
#define bm_calib_07    0x8f
#define bm_calib_08    0x90
#define bm_calib_09    0x91
#define bm_calib_10    0x92
#define bm_calib_11    0x93
#define bm_calib_12    0x94
#define bm_calib_13    0x95
#define bm_calib_14    0x96
#define bm_calib_15    0x97
#define bm_calib_16    0x98
#define bm_calib_17    0x99
#define bm_calib_18    0x9a
#define bm_calib_19    0x9b
#define bm_calib_20    0x9c
#define bm_calib_21    0x9d
#define bm_calib_22    0x9e
#define bm_calib_23    0x9f
#define bm_calib_24    0xa0
#define bm_calib_25    0xa1

#define bm_reset_command 0xb6
#define osrs_h_0         0x00
#define osrs_h_1         0x01
#define osrs_h_2         0x02
#define osrs_h_4         0x03
#define osrs_h_8         0x04
#define osrs_h_16        0x05

#define osrs_p_0         0x00
#define osrs_p_1         0x01
#define osrs_p_2         0x02
#define osrs_p_4         0x03
#define osrs_p_8         0x04
#define osrs_p_16        0x05

#define osrs_t_0         0x00
#define osrs_t_1         0x01
#define osrs_t_2         0x02
#define osrs_t_4         0x03
#define osrs_t_8         0x04
#define osrs_t_16        0x05

#define bm_mode_sleep    0x00
#define bm_mode_normal   0x03
#define bm_mode_force    0x01

#define bm_enable_spi3   0x01
#define bm_disable_spi3  0x00

#define t_sb_0_5         0x01
#define t_sb_62_5        0x02
#define t_sb_125         0x03
#define t_sb_250         0x04
#define t_sb_500         0x05
#define t_sb_1000        0x06
#define t_sb_10          0x07
#define t_sb_20          0x08

#define filter_off       0x00
#define filter_2         0x01
#define filter_4         0x02
#define filter_8         0x03
#define filter_16        0x04



extern volatile uint32_t timereset;

void ReadBurstReg(uint8_t adress, uint8_t *value, uint8_t i2cadress, uint8_t size);
uint8_t ReadReg(uint8_t adress, uint8_t i2cadress);
void WriteReg(uint8_t adress, uint8_t value, uint8_t i2cadress);
void WriteBurstReg(uint8_t adress, uint8_t *value, uint8_t i2cadress, uint8_t size);
uint8_t ReadStatus(void);
uint8_t CheckStatus(void);
uint8_t ReadID(void);
void CTRLMeasure(uint8_t t, uint8_t p, uint8_t mode);
void SetConfig(uint8_t tsb, uint8_t filter, uint8_t spi3);
void ResetBM(void);
void CTRLHumidity(uint8_t h);
void Init_BME280(void);
uint32_t getP_BM280(void);
uint32_t getT_BM280(void);
uint32_t getH_BM280(void);
void ReadDigi(uint8_t  *s);
uint8_t CheckCopyTrim(void);
void Readtrims(BME280_trimstruct * trimtrim);
int32_t measureT(BME280_trimstruct * digT);
uint32_t measureP(BME280_trimstruct * digP);
uint32_t measureH(BME280_trimstruct * digH);

#endif
