#include "stm32f10x.h"
#include "grafiki.h"

#define thresholdADC 600
#define histeresisADC 100

//-----------------------------------------------------
//Funkcja sprzetowe
void GPIO_Config(void);
void NVIC_Config(void);
void RCC_Config(void);
void I2C_Config(void);
void SPI_init(void);
void TIM_Config(void);
void DMA_Config(void);
void ADC_Config(void);
//-----------------------------------------------------
//Funkcje uzytkowe
void delay(uint32_t ms);
void animebelt(void);
void putlcdtemp(uint16_t x, uint16_t y, int32_t *temperatur);
void putlcdhum(uint16_t x, uint16_t y, int32_t *humidity);
void putlcdpress(uint16_t x, uint16_t y, int32_t *pressure);
void dimingled(uint16_t *diming);
void backlightregulation(void);
//-----------------------------------------------------
//Zmienne globalne
volatile uint32_t timereset, TIMERUS, timebelt, timermeas, timerbacklight;
BME280_trimstruct  trimbme;
uint8_t idvalue, i;
int32_t mp, mt, mh, bp, bt, bh, var;
unsigned long int valueADC;   //zmienna potrzebna w ukladzie DMA do ktorej jest przepisywana wartosc z przetwornika
uint16_t vardimer;  //zmienna ktora przyjmuje wartosc z zakresu 0 do 7600;
int chosefont;



int main(void)
{
	//Konfiguracja peryferiow
	RCC_Config();
	NVIC_Config();
	GPIO_Config();
	I2C_Config();
    SPI_init();
    TIM_Config();

    //zalaczenie przetwornika ADC oraz ukladu DMA odpowiedzialnych za pomiar
    ADC_Config();
    DMA_Config();

	if (SysTick_Config_Mod(SysTick_CLKSource_HCLK_Div8, 900)) //przerwanie co 0,1ms
	{
		while(1);		// W razie bledu petla nieskonczona
	}

	ILI9341_InitLCD();  //Inicjalizacja TFT
	putwallpaper(wall); //Wyswietlenie grafiki na wyswietlaczu



	//Odczekanie 5ms aby prawidlowo nastapilo uruchomienie
	delay(50);
	Init_BME280(); //Inicjalizacja czujnika BME280
	idvalue= ReadID(); //Odczytanie ID urzadzenia
	Readtrims(&trimbme); //odczytanie wspolczynnikow korekcyjnych

	//Uruchomienie konwersji dla przetwornika ADC
	ADC_SoftwareStartConvCmd(ADC1, ENABLE);

	//-----------------------------------------------------------------------------
	//Glowna petla programu
	while(1)
	{
		//Napisanie informacji
		 chosefont=5;
	     tft_mputs( 89, 24, "Temperatura", White, Blue1,wall);
	     tft_mputs( 102, 90, "Cinienie", White, Blue1,wall);
	     tft_mputs( 102, 155,"Wilgotno", White, Blue1,wall);



		while(1)
		{
			animebelt(); //animowane paski przezroczystosci

			      //Odczytanie wartosci temperatury cisnienia, wilgotnosci
				 if(!timermeas)
				 {
				 timermeas=500;
				 bt+=measureT(&trimbme);
				 bp+=measureP(&trimbme);
				 bh+=measureH(&trimbme);
				 var++;
				 if(var==10)
				 {
					 mt=bt/10;
					 mp=bp/10;
					 mh=bh/10;
					 bt=0;
					 bp=0;
					 bh=0;
					 var=0;
				 }
				 }
				 putlcdtemp(69, 47, &mt);
				 putlcdhum(69, 178, &mh);
				 putlcdpress(30, 113, &mp);

				  dimingled(&vardimer); //zmiana jasnosci
				  backlightregulation(); //funkcja sprawdzajaca zmiane wartosci
		}

	} //koniecc glownej petli programu
	//-----------------------------------------------------------------------------
}

//---------------------------------------------------------------------------------
//Inicjalizacja peryferiow
void GPIO_Config(void)
{

	  GPIO_InitTypeDef  GPIO_InitStructure;
	  //****************************************************************************
	 //Piny sterujace
	    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	    GPIO_Init(GPIOC, &GPIO_InitStructure);

	    GPIOC->BSRR=GPIO_Pin_8;

	  //Konfiguracja I2C
	  //PB6 - SCL  PB7 - SDA
	    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_10MHz;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_OD;
	    GPIO_Init(GPIOB, &GPIO_InitStructure);

	    //konfigurowanie portow GPIO dla wyswietlacza
	    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_Init(GPIOA, &GPIO_InitStructure);

	      GPIOA->BSRR = GPIO_Pin_4;

	    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_Init(GPIOA, &GPIO_InitStructure);

	    GPIOA->BSRR = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;

	    //*********************************************************************************
	    //Dla kontroli sterowania wyswietlacz Pin10 reset , Pin10 CSRW Pin11 ewentualny nSS
	    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_11 | GPIO_Pin_10 | GPIO_Pin_9;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	    GPIO_Init(GPIOA, &GPIO_InitStructure);

	    GPIOA ->BSRR = GPIO_Pin_9 | GPIO_Pin_10 | GPIO_Pin_11;

	    //Wyjscie dla ukladu PWM odpowiedzialnego za jasnosc wyswietlacza
	     GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
	     GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	     GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP; //wyjscie alternatywne o wysokiej impedancji
	     GPIO_Init(GPIOB, &GPIO_InitStructure);

	    //Konfiguracja wejscia przetwornika jako wejscia analogowego
	     GPIO_InitStructure.GPIO_Pin = GPIO_Pin_1;
	     GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
	     GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	     GPIO_Init(GPIOA, &GPIO_InitStructure);


}

void NVIC_Config(void)
{
	NVIC_InitTypeDef    NVIC_InitStructure;

	NVIC_InitStructure.NVIC_IRQChannel =SysTick_IRQn ; //tutaj trzeba zwrocic uwage na definicje w pliu stm32f10x.h
	//******************************************************************************************************************
  	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 1;
  	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  	NVIC_Init(&NVIC_InitStructure);
}

void I2C_Config(void)
{

	I2C_InitTypeDef    I2C_InitStructure;

    	I2C_DeInit(I2C1);
	    I2C_InitStructure.I2C_Mode = I2C_Mode_I2C;
	    I2C_InitStructure.I2C_DutyCycle =  I2C_DutyCycle_2;
	    I2C_InitStructure.I2C_OwnAddress1 =  0x41;
	    I2C_InitStructure.I2C_Ack = I2C_Ack_Enable;
	    I2C_InitStructure.I2C_AcknowledgedAddress = I2C_AcknowledgedAddress_7bit;
	    I2C_InitStructure.I2C_ClockSpeed = 10000;

	    I2C_Init(I2C1, &I2C_InitStructure);
	    I2C_Cmd(I2C1, ENABLE);
	    I2C_AcknowledgeConfig(I2C1, ENABLE);


}

//ustawienie sygnalow zegarowych
void RCC_Config(void)
{
	  RCC_DeInit();                                          //Reset ustawien RCC
	  RCC_HSEConfig(RCC_HSE_ON);                             //Wlaczenie HSE



		RCC_HCLKConfig(RCC_SYSCLK_Div1);                     //ustaw HCLK=SYSCLK
		RCC_PCLK2Config(RCC_HCLK_Div1);                      //ustaw PCLK2=HCLK
		RCC_PCLK1Config(RCC_HCLK_Div1);                      //ustaw PCLK1=HCLK/2
	    RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_9); //ustaw PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz

	    RCC_PLLCmd(ENABLE);                                  //wlacz PLL
	    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET){}  //odczekaj na poprawne uruchomienie PLL
	    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           //ustaw PLL jako zrodlo sygnalu zegarowego
	    while(RCC_GetSYSCLKSource() != 0x08){}                //odczekaj az PLL bedzie sygnalem zegarowym systemu

	  /*kod zwiazany z konfiguracja sygnalow zegarowych potrzebnych w programie peryferiow*/
	    RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO, ENABLE);

	        RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
	        RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);
	        RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);

	        RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1, ENABLE); //zalaczenie taktowania SPI1 dla wyswietlacza
	        RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C1, ENABLE);
	        RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE); //wlacz taktowanie TIM3

	        //Zalaczenie szyn odpowiedzialnych za pomiary wartosci
	        RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE); //wlacz taktowanie ADC1
	        //Podzia czestotliwosci dla ADC
	        RCC_ADCCLKConfig(RCC_PCLK2_Div8);

	        RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);   //wlacz taktowanie DMA


			SystemCoreClockUpdate();
}

//ustawienie interfejsu szeregowego dla wyswietlacza
void SPI_init(void)
{
   SPI_InitTypeDef  SPI_InitStructure;    //definicja obiektu stuktury

   SPI_I2S_DeInit(SPI1);

   SPI_InitStructure.SPI_Direction = SPI_Direction_2Lines_FullDuplex;    //ustawienie trybu 2 lini - MOSI i MISO
   SPI_InitStructure.SPI_DataSize = SPI_DataSize_8b;                     //ustawienie dlugosci danych przesylanych
   SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;                            //zegar w stanie niskim
   SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge;                          //reakcja na pierwsze zbocze zegarowe
   SPI_InitStructure.SPI_NSS = SPI_NSS_Hard;							 //ustawienie obslugi wyjscia CS programowo
   SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_2;    //preskaler dla zegara taktujacego SPI - 48Mhz/2=24Mhz
   SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;   				 //ustawienie najbardziej znacxacego bitu jako wysylany pierwszy
   SPI_InitStructure.SPI_CRCPolynomial = 0;                              //kontrola przeslanych bitow
   SPI_InitStructure.SPI_Mode = SPI_Mode_Master;   						 //tryb master
   SPI_Init(SPI1, &SPI_InitStructure);									 //wpisanie parametrow do struktury SPI1
   SPI_SSOutputCmd(SPI1, ENABLE);
   SPI_Cmd(SPI1, ENABLE);												 //funkcja zalaczajaca interfejs szerego SPI
}

//Konifurowanie PWM dla mozliwosci zmiany jasnosci
void TIM_Config(void)
{
  //konfigurowanie licznikow

	//***************************************************************************************************
	//Poczatek konfiguracja timer3 odpowiedzialnego za jasnosc wyswietlacza
	//***************************************************************************************************

  TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
  TIM_OCInitTypeDef  TIM_OCInitStructure;

  // Konfiguracja TIM3
  // Ustawienia ukladu podstawy czasu
  TIM_TimeBaseStructure.TIM_Prescaler = 0;         //bez prescelera (prescaler=1)
  TIM_TimeBaseStructure.TIM_Period = 7999ul;      //czestotliwosc PWM =5,86kHz  poniewaz 72Mhz/8000=9kHz
  TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV1;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;

  TIM_TimeBaseInit(TIM3, &TIM_TimeBaseStructure);


  // Konfiguracja kanalu 3 - uzywamy kanalu 3 poniewaz jego wyjscie jest na GPIOB0
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1; //tryb pwm
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_Pulse = 0ul;          //poczatkowe wypelnienie maksymalne (TIMpulse/Timperiod)*100%=100%
  TIM_OCInitStructure.TIM_OCPolarity=TIM_OCPolarity_High;
  TIM_OC3Init(TIM3, &TIM_OCInitStructure);

  TIM_OC3PreloadConfig(TIM3, TIM_OCPreload_Enable);//wlaczenie buforowania

  TIM_ARRPreloadConfig(TIM3, ENABLE);//wlaczenie buforowania
  // Wlaczenie timera
  TIM_Cmd(TIM3, ENABLE);

}

//Konfiguracja ukladu DMA dla ADC
void DMA_Config(void)
{
  //konfigurowanie DMA

  #define ADC1_DR_Address 0x4001244C;                                             //adres rejestru ADC1->DR

  DMA_InitTypeDef DMA_InitStructure;

  DMA_DeInit(DMA1_Channel1);                                                      //Usun ewentualna poprzednia konfiguracje DMA

  DMA_InitStructure.DMA_PeripheralBaseAddr = (unsigned long int)ADC1_DR_Address;  //Adres docelowy transferu
  DMA_InitStructure.DMA_MemoryBaseAddr = (unsigned long int)&valueADC;            //Adres poczatku bloku do przeslania
  DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralSRC;                              //Kierunek transferu
  DMA_InitStructure.DMA_BufferSize = 1;                                           //Liczba elementow do przeslania (dlugosc bufora)
  DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;                //Wylaczenie automatycznego zwiekszania adresu po stronie ADC
  DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Disable;                         //Wylaczenie automatycznego zwiekszania adresu po stronie pamieci (bufora)
  DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord;     //Rozmiar pojedynczych przesylanych danych po stronie ADC (HalfWord = 16bit)
  DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_HalfWord;             //Rozmiar pojedynczych przesylanych danych po stronie pamieci (bufora)
  DMA_InitStructure.DMA_Mode = DMA_Mode_Circular;                                 //Tryb dzialania kontrolera DMA - powtarzanie cykliczne
  DMA_InitStructure.DMA_Priority = DMA_Priority_High;                             //Priorytet DMA - wysoki
  DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;                                    //Wylaczenie obslugi transferu z pamieci do pamieci
  DMA_Init(DMA1_Channel1, &DMA_InitStructure);                                    //Zapis konfiguracji

  //Wlacz DMA, kanal 1
  DMA_Cmd(DMA1_Channel1, ENABLE);
}

//Konfiguracja ADC
void ADC_Config(void)
{
  //konfigurowanie przetwornika AC
  ADC_InitTypeDef ADC_InitStructure;

	ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;                  //Jeden przetwornik, praca niezalezna
	ADC_InitStructure.ADC_ScanConvMode = DISABLE;                        //Pomiar jednego kanalu, brak skanowania kanalow
    ADC_InitStructure.ADC_ContinuousConvMode = ENABLE;                  //Pomiar w trybie ciaglym
	ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_None;	//Brak wyzwalania zewnetrznego
	ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;            	//Wyrownanie danych do prawej - 12 mlodszych bitow znaczacych
	ADC_InitStructure.ADC_NbrOfChannel = 1; 	                          //Liczba uzywanych kanalow =1
	ADC_Init(ADC1, &ADC_InitStructure);                                 //Incjalizacja przetwornika

    ADC_RegularChannelConfig(ADC1, ADC_Channel_1, 1, ADC_SampleTime_239Cycles5);
                                                                      //Kanal 1 - GPIOA1
                                                                      //Grupa podstawowa, czas probkowania 41,5+12,5 cykli (calkowity czas przetwarania)
   ADC_DMACmd(ADC1,ENABLE);                                            //Wlaczenie DMA dla ADC
   ADC_Cmd(ADC1, ENABLE);	                                            //Wlacz ADC1

   ADC_ResetCalibration(ADC1);	                                        //Reset rejestrow kalibracyjnych ADC1
   while(ADC_GetResetCalibrationStatus(ADC1));	                        //Odczekanie na wykonanie resetu
   ADC_StartCalibration(ADC1);	                                        //Kalibracja ADC1
   while(ADC_GetCalibrationStatus(ADC1));    	                        //Odczekanie na zakonczenie kalibracji ADC1
}
//--------------------------------------------------------------------------------------------------------
//Funkcje uzytkowe
void delay(uint32_t ms)
{
	TIMERUS=ms*10;
	while(TIMERUS);
}
//Paski animowane u gory oraz u dolu wyswietlacza
void animebelt(void)
{
	static uint8_t flagas=1, wart=0;

	if(!timebelt)
	{
		if(flagas)
		{
			wart++;
			if(wart>14) flagas=0;
		}
		else
		{
			if(wart) wart--;
			else flagas=1;
		}

		putrectfromwallpaper(10, 10, 310, 20, wall, wart);
		putrectfromwallpaper(10, 220, 310, 230, wall, wart);

		timebelt=800;
	}

}

void dimingled(uint16_t *diming)
{
	    static uint16_t startup=0;
	    static uint16_t tempdim=0;

	    if(!timerbacklight)
	    {

	    	if(startup<199) {
	    		timerbacklight=20;
	    		startup++;
	    		TIM3->CCR3=(startup);
	    	}
	    	else
	    		{
	    		timerbacklight=5;
	    		if(tempdim<(*diming)) tempdim++;
	    		else if(tempdim>(*diming)) if(tempdim) tempdim--;
	    		TIM3->CCR3=(startup + tempdim);
	    		}

	    }

}

//Funkcja wypisujaca wartosci na wyswietlaczu
void putlcdtemp(uint16_t x, uint16_t y, int32_t *temperatur)
{
	static int32_t temptemp=0xffffffff;
	uint32_t temp2,temp3;
	static uint8_t firststart=1;

	 char l1[2]={0x00, 0x00};
	 char l2[2]={0x00, 0x00};
	 char l3[2]={0x00, 0x00};
	 char l4[2]={0x00, 0x00};


	 static char tt[5]={0xff, 0xff, 0xff, 0xff, 0xff};

	 if(firststart)
	 {
		 firststart=0;
		 chosefont=1;

		 tft_mputs( x+52, y, ",", White, Blue1,wall);
		 tft_mputs( x+130, y, "C", White, Blue1,wall);
	 }

	if(temptemp!=*temperatur)
	{
		chosefont=1;

		temptemp=*temperatur;

		if(temptemp & 0x80000000)
		{
			temptemp=~temptemp;
			temptemp+=1;

			full_rect3( x-15, y+14, x-1, y+21, White);
		}
		else
		{
			putrectfromwallpaper(x-15, y+14, x-1, y+21, wall, 0);
		}

	 l1[0]=temptemp/1000;
	 temp2=temptemp-l1[0]*1000;
	 l2[0]=temp2/100;
	 temp3=temp2-l2[0]*100;
	 l3[0]=temp3/10;
	 l4[0]=temptemp%10;

	  l1[1]=0x00;
	  l2[1]=0x00;
	  l3[1]=0x00;
	  l4[1]=0x00;

	  l1[0]+=0x30;
	  l2[0]+=0x30;
	  l3[0]+=0x30;
	  l4[0]+=0x30;

	  if(l1[0]!=tt[1])
	  {
		  tt[1]=l1[0];
		  if(tt[1]==0x30)
		  {
			  putrectfromwallpaper(x, y, x+26, y+35, wall, 0);
		  }
		  else
		  tft_mputs( x, y, l1, White, Blue1,wall);
	  }
	  if(l2[0]!=tt[2])
	  	  {
	  		  tt[2]=l2[0];
	  		 tft_mputs( x+26, y, l2, White, Blue1,wall);
	  	  }
	  if(l3[0]!=tt[3])
	  	  {
	  		  tt[3]=l3[0];
	  		 tft_mputs( x+78, y, l3, White, Blue1,wall);
	  	  }
	  if(l4[0]!=tt[4])
	  	  {
	  		  tt[4]=l4[0];
	  		 tft_mputs( x+104, y, l4, White, Blue1,wall);
	  	  }
	}

}

//Funkcja wypisujaca wartosci na wyswietlaczu - wilgotnosc
void putlcdhum(uint16_t x, uint16_t y, int32_t *humidity)
{
	static uint32_t temptemp=0xffffffff;
	uint32_t temp2,temp3, temp4;
	static uint8_t firststart=1;
	 static char tt[6]={0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
	 static uint8_t flagaa=0;

	 char l1[2]={0x00, 0x00};
	 char l2[2]={0x00, 0x00};
	 char l3[2]={0x00, 0x00};
	 char l4[2]={0x00, 0x00};
	 char l5[2]={0x00, 0x00};


	 if(firststart)
	 {
		 firststart=0;
		 chosefont=1;

		 tft_mputs( x+78, y, ",", White, Blue1,wall);
		 tft_mputs( x+156, y, "%", White, Blue1,wall);
	 }

	if(temptemp!=*humidity)
	{
		chosefont=1;

		temptemp=*humidity;

	 l1[0]=temptemp/10000;
	 temp2=temptemp-l1[0]*10000;
	 l2[0]=temp2/1000;
	 temp3=temp2-l2[0]*1000;
	 l3[0]=temp3/100;
	 temp4=temp3-l3[0]*100;
	 l4[0]=temp4/10;
	 l5[0]=temptemp%10;

	  l1[1]=0x00;
	  l2[1]=0x00;
	  l3[1]=0x00;
	  l4[1]=0x00;
	  l5[1]=0x00;

	  l1[0]+=0x30;
	  l2[0]+=0x30;
	  l3[0]+=0x30;
	  l4[0]+=0x30;
	  l5[0]+=0x30;

	  if(l1[0]!=tt[1])
	  {
		  tt[1]=l1[0];
		    if(tt[1]==0x30)
		    {
		 		  putrectfromwallpaper(x, y, x+26, y+35, wall, 0);
		 		  flagaa=1;
		    }
		    else
		    {
		    tft_mputs( x, y, l1, White, Blue1,wall);
		    if(flagaa)
		     {
		    	 flagaa=0;
		    	 tt[1]=0xff;
		    	 tt[2]=0xff;
		    	 tt[0]=0xff;
		      }
		    }
	  }
	  if(l2[0]!=tt[2])
	  	  {
	  		  tt[2]=l2[0];
	  		   if((tt[1]==0x30) && (tt[2]==0x30))
	  			{
	  				 putrectfromwallpaper(x+26, y, x+52, y+35, wall, 0);
	  				 flagaa=1;
	  			}
	  			else
	  			{
	  		 tft_mputs( x+26, y, l2, White, Blue1,wall);
	  		 if(flagaa)
	  		 {
	  			 flagaa=0;
	  			 tt[1]=0xff;
	  			 tt[2]=0xff;
	  			 tt[0]=0xff;
	  		 }
	  			}
	  	  }
	  if(l3[0]!=tt[3])
	  	  {
	  		  tt[3]=l3[0];
	  		 tft_mputs( x+52, y, l3, White, Blue1,wall);
	  	  }
	  if(l4[0]!=tt[4])
	  	  {
	  		  tt[4]=l4[0];
	  		 tft_mputs( x+104, y, l4, White, Blue1,wall);
	  	  }
	  if(l5[0]!=tt[5])
		  	  {
		  		  tt[5]=l5[0];
		  		 tft_mputs( x+130, y, l5, White, Blue1,wall);
		  	  }
	}

}

//Funkcja wypisujaca wartosci na wyswietlaczu - cisnienie
void putlcdpress(uint16_t x, uint16_t y, int32_t *pressure)
{
	static uint32_t temptemp=0xffffffff;
	uint32_t temp2,temp3, temp4, temp5;
	static uint8_t firststart=1;
	static uint8_t flagaa=0;

	 char l1[2]={0x00, 0x00};
	 char l2[2]={0x00, 0x00};
	 char l3[2]={0x00, 0x00};
	 char l4[2]={0x00, 0x00};
	 char l5[2]={0x00, 0x00};
	 char l6[2]={0x00, 0x00};


	 static char tt[7];

	 if(firststart)
	 {
		 firststart=0;
		 chosefont=1;

		 tft_mputs( x+104, y, ",", White, Blue1,wall);
		 tft_mputs( x+182, y, "hPa", White, Blue1,wall);

		 tt[0]=0xff;
		 tt[1]=0xff;
		 tt[2]=0xff;
		 tt[3]=0xff;
		 tt[4]=0xff;
		 tt[5]=0xff;
		 tt[6]=0xff;
	 }

	if(temptemp!=*pressure)
	{
		chosefont=1;

		temptemp=*pressure;

	 l1[0]=temptemp/100000;
	 temp2=temptemp-l1[0]*100000;
	 l2[0]=temp2/10000;
	 temp3=temp2-l2[0]*10000;
	 l3[0]=temp3/1000;
	 temp4=temp3-l3[0]*1000;
	 l4[0]=temp4/100;
	 temp5=temp4-l4[0]*100;
	 l5[0]=temp5/10;
	 l6[0]=temptemp%10;

	  l1[1]=0x00;
	  l2[1]=0x00;
	  l3[1]=0x00;
	  l4[1]=0x00;
	  l5[1]=0x00;
	  l6[1]=0x00;

	  l1[0]+=0x30;
	  l2[0]+=0x30;
	  l3[0]+=0x30;
	  l4[0]+=0x30;
	  l5[0]+=0x30;
	  l6[0]+=0x30;


	  if(l1[0]!=tt[1])
	  {
		  tt[1]=l1[0];

		  if(tt[1]=='0')
		  {
		 	    putrectfromwallpaper(x, y, x+26, y+35, wall, 0);
		 	    flagaa=1;
		  }
		  else
		  {
		  tft_mputs( x, y, l1, White, Blue1,wall);

		  if(flagaa)
		  {
			  flagaa=0;
				 tt[0]=0xff;
				 tt[1]=0xff;
				 tt[2]=0xff;
				 tt[2]=0xff;
		  }
		  }
	  }
	  if(l2[0]!=tt[2])
	  	  {
	  		  tt[2]=l2[0];

	  	 if((tt[1]=='0') && (tt[2]=='0'))
	  		 {
	  			putrectfromwallpaper(x+26, y, x+52, y+35, wall, 0);
	  			flagaa=1;
	  		 }
	  		 else
	  		 {
	  		 tft_mputs( x+26, y, l2, White, Blue1,wall);

			  if(flagaa)
			  {
				  flagaa=0;
					 tt[0]=0xff;
					 tt[1]=0xff;
					 tt[2]=0xff;
					 tt[2]=0xff;
			  }
	  		 }
	  	  }
	  if(l3[0]!=tt[3])
	  	  {
	  		 tt[3]=l3[0];

	 		 if((tt[1]=='0') && (tt[2]=='0') && (tt[3]=='0'))
	  		 {
	  			  putrectfromwallpaper(x+52, y, x+78, y+35, wall, 0);
	  			  flagaa=1;
	  		 }
	  		 else
	  		 {
	  		 tft_mputs( x+52, y, l3, White, Blue1,wall);

			  if(flagaa)
			  {
				  flagaa=0;
					 tt[0]=0xff;
					 tt[1]=0xff;
					 tt[2]=0xff;
					 tt[2]=0xff;
			  }
	  		 }
	  	  }
	  if(l4[0]!=tt[4])
	  	     {
	  		     tt[4]=l4[0];
	  		      tft_mputs( x+78, y, l4, White, Blue1,wall);
	  	      }
	  if(l5[0]!=tt[5])
		  	  {
		  		 tt[5]=l5[0];
		  		 tft_mputs( x+130, y, l5, White, Blue1,wall);
		  	  }
	  if(l6[0]!=tt[6])
			  {
			  	  tt[6]=l6[0];
			  	  tft_mputs( x+156, y, l6, White, Blue1,wall);
			  }
	}

}

//regulacja jasnosci
void backlightregulation(void)
{
		//thresholdADC 2048
		//histeresisADC 100

		static uint8_t  incdec=1;

		if(valueADC>(thresholdADC+histeresisADC)) incdec=1; else if(valueADC<(thresholdADC-histeresisADC)) incdec=0;

		if(incdec)
		{
			if(vardimer<7800) vardimer++;
		}
		else
		{
			if(vardimer) vardimer--;
		}
}


